@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2001, 2002, 2003 Philip Blundell <philb@gnu.org>
+ * Hildon adaption 2005 by Matthias Steinbauer <matthias@steinbauer.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +27,16 @@
 
 #include <gpe/event-db.h>
 
+#ifdef IS_HILDON
+/* Hildon includes */
+#include <hildon-widgets/hildon-app.h>
+#include <hildon-widgets/hildon-appview.h>
+#include <gpe/pim-categories-ui.h>
+#include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
+#include <libosso.h>
+#define APPLICATION_DBUS_SERVICE "gpe-calendar"
+#endif
+
 #include "event-ui.h"
 #include "globals.h"
 
@@ -35,7 +46,6 @@
 #include "import-vcal.h"
 #include "gtkdatesel.h"
 
-#include <libdisplaymigration/displaymigration.h>
 #include <gpe/pim-categories.h>
 
 #include <locale.h>
@@ -246,7 +256,7 @@ button_toggled (GtkWidget *widget, gpointer data)
 static void
 gpe_cal_exit (void)
 {
-  schedule_next (0, 0);
+  schedule_next (0, 0, NULL);
   event_db_stop ();
   gtk_main_quit ();
 }
@@ -366,12 +376,42 @@ main_window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *data)
   return FALSE;
 }
 
+#ifdef IS_HILDON
+static void
+create_app_menu(HildonAppView *appview)
+{
+  GtkMenu *main_menu;
+  GtkWidget *item_appointment, *item_today, *item_day, *item_week,
+    *item_month, *item_import, *item_toolbar;
+
+  main_menu = hildon_appview_get_menu(appview);
+
+  item_appointment = gtk_menu_item_new_with_label(_("New appointment"));
+  g_signal_connect(G_OBJECT(item_appointment), "activate", G_CALLBACK(new_appointment), NULL);
+  gtk_menu_append(main_menu, item_appointment);
+
+  item_today = gtk_menu_item_new_with_label(_("Today"));
+  g_signal_connect(G_OBJECT(item_today), "activate", set_today, NULL);
+  gtk_menu_append(main_menu, item_today);
+
+  item_import = gtk_menu_item_new_with_label(_("Import"));
+  g_signal_connect(G_OBJECT(item_import), "activate", G_CALLBACK(on_import_vcal), NULL);
+  gtk_menu_append(main_menu, item_import);
+
+  gtk_widget_show_all(main_menu);
+}
+#endif
+	 
 int
 main (int argc, char *argv[])
 {
   GtkWidget *vbox, *toolbar;
   GdkPixbuf *p;
   GtkWidget *pw;
+#ifdef IS_HILDON
+  GtkWidget *app, *main_appview;
+  osso_context_t *osso_context;
+#endif
 
   guint hour, skip=0, uid=0;
   int option_letter;
@@ -391,8 +431,6 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
-  displaymigration_init ();
-
   if (event_db_start () == FALSE)
     exit (1);
 
@@ -413,7 +451,7 @@ main (int argc, char *argv[])
 		ifile = optarg;
     }
 
-  schedule_next (skip, uid);
+  schedule_next (skip, uid, NULL);
 
   if (schedule_only)
     exit (EXIT_SUCCESS);
@@ -460,29 +498,51 @@ main (int argc, char *argv[])
   window_y = gdk_screen_height() / 2;  
   if (window_x < 240) window_x = 240;
   if (window_y < 310) window_y = 310;
-    
+#ifdef IS_HILDON
+  app = hildon_app_new();
+  hildon_app_set_two_part_title(HILDON_APP(app), FALSE);
+  hildon_app_set_title(HILDON_APP(app), _("Calendar"));
+  main_appview = hildon_appview_new(_("Main"));
+  hildon_app_set_appview(HILDON_APP(app), HILDON_APPVIEW(main_appview));
+  main_window = main_appview;
+#else    
   main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (main_window), _("Calendar"));
   g_signal_connect (G_OBJECT (main_window), "delete-event",
                     G_CALLBACK (gpe_cal_exit), NULL);
   gtk_window_set_default_size (GTK_WINDOW (main_window), window_x, window_y);
 
-  displaymigration_mark_window (main_window);
-
   gtk_widget_realize (main_window);
+#endif
 
+#ifdef IS_HILDON
+  /* Initialize maemo application */
+  osso_context = osso_initialize(
+  APPLICATION_DBUS_SERVICE, "0.1", TRUE, NULL);
+
+  /* Check that initialization was ok */
+  if (osso_context == NULL)
+  {
+    return OSSO_ERROR;
+  }
+#endif
+	 
   gtk_container_add (GTK_CONTAINER (main_window), vbox);
 
   time (&viewtime);
   week = week_view ();
   day = day_view ();
   month = month_view ();
+  
   toolbar = gtk_toolbar_new ();
-
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar), GTK_ORIENTATION_HORIZONTAL);
   GTK_WIDGET_UNSET_FLAGS(toolbar, GTK_CAN_FOCUS);
 
+#ifndef IS_HILDON
   gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
+#else
+  hildon_appview_set_toolbar(HILDON_APPVIEW(main_appview), GTK_TOOLBAR(toolbar));
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
 
   pw = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_NEW,
@@ -538,14 +598,20 @@ main (int argc, char *argv[])
 			    _("Import"), _("Open file to import an event from it."), 
                 NULL, pw, G_CALLBACK (on_import_vcal), NULL);
   GTK_WIDGET_UNSET_FLAGS(pw, GTK_CAN_FOCUS);
-              
+
+#ifndef IS_HILDON
   gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
 
   pw = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_QUIT,
-		                 	     _("Tap here to exit the program"), NULL, 
-			                     G_CALLBACK (gpe_cal_exit), NULL, -1);
+					_("Tap here to exit the program"), NULL, 
+					G_CALLBACK (gpe_cal_exit), NULL, -1);
   GTK_WIDGET_UNSET_FLAGS(pw, GTK_CAN_FOCUS);
+#endif
 
+#ifdef IS_HILDON
+  create_app_menu(main_appview);
+#endif
+	 
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 
   gtk_widget_show (day);
@@ -567,6 +633,9 @@ main (int argc, char *argv[])
 
   gpe_set_window_icon (main_window, "icon");
 
+#ifdef IS_HILDON  
+  gtk_widget_show_all(app);
+#endif
   gtk_widget_show (main_window);
   gtk_widget_show (vbox);
   gtk_widget_show (toolbar);
